@@ -47,14 +47,15 @@ def remote_call(remote_endpoint):
 
         while True:
             recv_data = sock.recv(4096)
-            current_app.logger.debug('recv_data: %s', recv_data)
             if not recv_data:
-                yield '<pre>gourd server closed</pre>'
+                current_app.logger.debug()
+                yield '<pre>gourd server closed socket</pre>'
                 if unique_id in socket_map:
                     socket_map.pop(unique_id).close()
                 break
             else:
-                yield '<pre>%s</pre>' % recv_data
+                current_app.logger.debug('recv_data: %r', recv_data)
+                yield '<pre>%r</pre>' % recv_data
 
     return Response(stream_with_context(generate()))
 
